mgls

package
v2.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateMgl

func GenerateMgl(core *cores.Core, rbfPath, path, override string) (string, error)

func LaunchBasicFile

func LaunchBasicFile(path string) error

func LaunchCore

func LaunchCore(cfg *config.Instance, _ platforms.Platform, system *cores.Core) error

LaunchCore Launch a core given a possibly partial path, as per MGL files.

func LaunchGame

func LaunchGame(cfg *config.Instance, system *cores.Core, path string) error

func LaunchShortCore

func LaunchShortCore(path string) error

LaunchShortCore attempts to launch a core with a short path, as per what's allowed in an MGL file.

Types

type MGL

type MGL struct {
	XMLName xml.Name `xml:"mistergamedescription"`
	Rbf     string   `xml:"rbf"`
	SetName string   `xml:"setname"`
	File    MGLFile  `xml:"file"`
}

func ReadMgl

func ReadMgl(path string) (MGL, error)

type MGLFile

type MGLFile struct {
	XMLName xml.Name `xml:"file"`
	Type    string   `xml:"type,attr"`
	Path    string   `xml:"path,attr"`
	Delay   int      `xml:"delay,attr"`
	Index   int      `xml:"index,attr"`
}

type MRA added in v2.7.0

type MRA struct {
	XMLName xml.Name `xml:"misterromdescription"`
	SetName string   `xml:"setname"`
	Name    string   `xml:"name"`
	Rbf     string   `xml:"rbf"`
}

MRA represents the structure of a MiSTer Arcade ROM file.

func ReadMRA added in v2.7.0

func ReadMRA(path string) (MRA, error)

ReadMRA parses an MRA file and returns the MRA struct with extracted metadata.

Jump to