Documentation
¶
Index ¶
- func GenerateMgl(core *cores.Core, rbfPath, path, override string) (string, error)
- func LaunchBasicFile(path string) error
- func LaunchCore(cfg *config.Instance, _ platforms.Platform, system *cores.Core) error
- func LaunchGame(cfg *config.Instance, system *cores.Core, path string) error
- func LaunchShortCore(path string) error
- type MGL
- type MGLFile
- type MRA
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateMgl ¶
func LaunchBasicFile ¶
func LaunchCore ¶
LaunchCore Launch a core given a possibly partial path, as per MGL files.
func LaunchShortCore ¶
LaunchShortCore attempts to launch a core with a short path, as per what's allowed in an MGL file.
Types ¶
type MGL ¶
Click to show internal directories.
Click to hide internal directories.